<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2011 Nicole Cordes <cordes@cps-it.de>, CPS-IT GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 * @author Nicole Cordes
 * @package
 * @subpackage
 */

class tx_countries_backendfunctions implements t3lib_Singleton {

	/**
	 * Get countries for TCA select field
	 *
	 * @static
	 * @param array $params
	 * @return void
	 */
	public static function getCountriesTCASelectFields($params) {
		// Get language
		$typo3Language = strtoupper($params['language'] ? $params['language'] : tx_countries_div::getLanguage());

		// Get all countries
		$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery(($typo3Language == 'EN' ? 'uid' : 'l18n_parent AS uid') . ', cn_title', 'countries', 'lang_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr($typo3Language, 'countries') . t3lib_BEfunc::deleteClause('countries'), '', 'cn_title, lang_iso2');

		// Fallback to english countries
		if (!$GLOBALS['TYPO3_DB']->sql_num_rows($result)) {
			$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('uid, cn_title', 'countries', 'lang_iso2="EN"' . t3lib_BEfunc::deleteClause('countries'), '', 'cn_title, lang_iso2');
		}

		// Add items to array
		while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($result)) {
			$params['items'][] = array($row['cn_title'], $row['uid']);
		}

		// Free DB result
		$GLOBALS['TYPO3_DB']->sql_free_result($result);
	}

	/**
	 * Get subdivisions for TCA select field
	 *
	 * @static
	 * @param array $params
	 * @return void
	 */
	public static function getSubdivisionsTCASelectFields($params) {
		// Get language
		$typo3Language = strtoupper($params['language'] ? $params['language'] : tx_countries_div::getLanguage());

		// If country field in current configuration is defined
		if (isset($params['row'][$params['config']['itemsProcFunc_config']['country']]) AND $params['row'][$params['config']['itemsProcFunc_config']['country']]) {

			$iso2 = current(tx_countries_frontendfunctions::getCountryFieldsById($params['row'][$params['config']['itemsProcFunc_config']['country']], 'cn_iso2'));

			// Get subdivisions for current country in proper language
			$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery(($typo3Language == 'EN' ? 'uid' : 'l18n_parent AS uid') . ', sd_title', 'subdivisions', 'lang_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr($typo3Language, 'subdivisions') . ' AND sd_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr($iso2, 'subdivision') . t3lib_BEfunc::deleteClause('subdivisions'), '', 'sd_title, lang_iso2');

			// Fallback to english subdivisions
			if (!$GLOBALS['TYPO3_DB']->sql_num_rows($result)) {
				$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('uid, sd_title', 'subdivisions', 'lang_iso2="EN" AND sd_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr($iso2, 'subdivision') . t3lib_BEfunc::deleteClause('subdivisions'), '', 'sd_title, lang_iso2');
			}

			// Append items to array
			while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($result)) {
				$params['items'][] = array($row['sd_title'], $row['uid']);
			}

			// Free DB result
			$GLOBALS['TYPO3_DB']->sql_free_result($result);
		}
	}

}

?>