<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2011 Nicole Cordes <cordes@cps-it.de>, CPS-IT GmbH
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 3 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 *
 * @author Nicole Cordes
 * @package
 * @subpackage
 */

class tx_countries_frontendfunctions implements t3lib_Singleton {

	/**
	 * Get fields for a country in proper language
	 *
	 * @static
	 * @param int $id
	 * @param mixed $fields
	 * @param string $language
	 *
	 * @return array
	 */
	public static function getCountryFieldsById($id, $fields, $language = '') {
		settype($id, 'integer');

		$return = array();

		// Explode fields to array
		if (!is_array($fields)) {
			$fields = array($fields);
		}

		// Get language
		if (!$language) $language = tx_countries_div::getLanguage();

		// Get field(s) in proper language
		$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('countries.*', 'countries', (strtolower($language) == 'en' ? 'uid' : 'l18n_parent') . '=' . $id . ' AND lang_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($language), 'countries') . t3lib_BEfunc::deleteClause('countries'), '', '', '1');
		// If no countries for language were found -> fetch default
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($result) < 1) {
			$language = 'en';
			$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('countries.*', 'countries', (strtolower($language) == 'en' ? 'uid' : 'l18n_parent') . '=' . $id . ' AND lang_iso2='. $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($language), 'countries') . t3lib_BEfunc::deleteClause('countries'), '', '', '1');
		}

		if ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($result)) {
			foreach ($fields as $key => $value) {
				$return[$key] = $row[$value];
			}
			unset($key, $value);
		}

		// Free DB result
		$GLOBALS['TYPO3_DB']->sql_free_result($result);

		return $return;
	}

	/**
	 * Get fields for a subdivision in proper language
	 *
	 * @static
	 * @param int $id
	 * @param mixed $fields
	 * @param string $language
	 *
	 * @return array
	 */
	public static function getSubdivisionFieldsById($id, $fields, $language = '') {
		settype($id, 'integer');

		$return = array();

		// Explode fields to array
		if (!is_array($fields)) {
			$fields = array($fields);
		}

		// Get language
		if (!$language) $language = tx_countries_div::getLanguage();

		// Get field(s) in proper language
		$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('subdivisions.*', 'subdivisions', (strtolower($language) == 'en' ? 'uid' : 'l18n_parent') . '=' . $id . ' AND lang_iso2=' . $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($language), 'subdivisions') . t3lib_BEfunc::deleteClause('subdivisions'), '', '', '1');
		// If no countries for language were found -> fetch default
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($result) < 1) {
			$language = 'en';
			$result = $GLOBALS['TYPO3_DB']->exec_SELECTquery('subdivisions.*', 'subdivisions', (strtolower($language) == 'en' ? 'uid' : 'l18n_parent') . '=' . $id . ' AND lang_iso2='. $GLOBALS['TYPO3_DB']->fullQuoteStr(strtoupper($language), 'subdivisions') . t3lib_BEfunc::deleteClause('subdivisions'), '', '', '1');
		}

		if ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($result)) {
			foreach ($fields as $key => $value) {
				$return[$key] = $row[$value];
			}
			unset($key, $value);
		}

		// Free DB result
		$GLOBALS['TYPO3_DB']->sql_free_result($result);

		return $return;
	}

}

?>